class TLDS:
    @staticmethod
    def generic_tlds():
        gtld_extensions = [
            'aaa',
            'aarp',
            'abarth',
            'abb',
            'abbott',
            'abbvie',
            'abc',
            'able',
            'abogado',
            'abudhabi',
            'academy',
            'accenture',
            'accountant',
            'accountants',
            'aco',
            'active',
            'actor',
            'adac',
            'ads',
            'adult',
            'aeg',
            'aetna',
            'afamilycompany',
            'afl',
            'africa',
            'agakhan',
            'agency',
            'aig',
            'aigo',
            'airbus',
            'airforce',
            'airtel',
            'akdn',
            'alfaromeo',
            'alibaba',
            'alipay',
            'allfinanz',
            'allstate',
            'ally',
            'alsace',
            'alstom',
            'amazon',
            'americanexpress',
            'americanfamily',
            'amex',
            'amfam',
            'amica',
            'amsterdam',
            'analytics',
            'android',
            'anquan',
            'anz',
            'aol',
            'apartments',
            'app',
            'apple',
            'aquarelle',
            'arab',
            'aramco',
            'archi',
            'army',
            'art',
            'arte',
            'asda',
            'associates',
            'athleta',
            'attorney',
            'auction',
            'audi',
            'audible',
            'audio',
            'auspost',
            'author',
            'auto',
            'autos',
            'avianca',
            'aws',
            'axa',
            'azure',
            'baby',
            'baidu',
            'banamex',
            'bananarepublic',
            'band',
            'bank',
            'bar',
            'barcelona',
            'barclaycard',
            'barclays',
            'barefoot',
            'bargains',
            'baseball',
            'basketball',
            'bauhaus',
            'bayern',
            'bbc',
            'bbt',
            'bbva',
            'bcg',
            'bcn',
            'beats',
            'beauty',
            'beer',
            'bentley',
            'berlin',
            'best',
            'bestbuy',
            'bet',
            'bharti',
            'bible',
            'bid',
            'bike',
            'bing',
            'bingo',
            'bio',
            'black',
            'blackfriday',
            'blanco',
            'blockbuster',
            'blog',
            'bloomberg',
            'blue',
            'bms',
            'bmw',
            'bnl',
            'bnpparibas',
            'boats',
            'boehringer',
            'bofa',
            'bom',
            'bond',
            'boo',
            'book',
            'booking',
            'boots',
            'bosch',
            'bostik',
            'boston',
            'bot',
            'boutique',
            'box',
            'bradesco',
            'bridgestone',
            'broadway',
            'broker',
            'brother',
            'brussels',
            'budapest',
            'bugatti',
            'build',
            'builders',
            'business',
            'buy',
            'buzz',
            'bzh',
            'cab',
            'cafe',
            'cal',
            'call',
            'calvinklein',
            'cam',
            'camera',
            'camp',
            'cancerresearch',
            'canon',
            'capetown',
            'capital',
            'capitalone',
            'car',
            'caravan',
            'cards',
            'care',
            'career',
            'careers',
            'cars',
            'cartier',
            'casa',
            'case',
            'caseih',
            'cash',
            'casino',
            'catering',
            'catholic',
            'cba',
            'cbn',
            'cbre',
            'cbs',
            'ceb',
            'center',
            'ceo',
            'cern',
            'cfa',
            'cfd',
            'chanel',
            'channel',
            'charity',
            'chase',
            'chat',
            'cheap',
            'chintai',
            'chloe',
            'christmas',
            'chrome',
            'chrysler',
            'church',
            'cipriani',
            'circle',
            'cisco',
            'citadel',
            'citi',
            'citic',
            'city',
            'cityeats',
            'claims',
            'cleaning',
            'click',
            'clinic',
            'clinique',
            'clothing',
            'cloud',
            'club',
            'clubmed',
            'coach',
            'codes',
            'coffee',
            'college',
            'cologne',
            'com',
            'comcast',
            'commbank',
            'community',
            'company',
            'compare',
            'computer',
            'comsec',
            'condos',
            'construction',
            'consulting',
            'contact',
            'contractors',
            'cooking',
            'cookingchannel',
            'cool',
            'corsica',
            'country',
            'coupon',
            'coupons',
            'courses',
            'cpa',
            'credit',
            'creditcard',
            'creditunion',
            'cricket',
            'crown',
            'crs',
            'cruise',
            'cruises',
            'csc',
            'cuisinella',
            'cymru',
            'cyou',
            'dabur',
            'dad',
            'dance',
            'data',
            'date',
            'dating',
            'datsun',
            'day',
            'dclk',
            'dds',
            'deal',
            'dealer',
            'deals',
            'degree',
            'delivery',
            'dell',
            'deloitte',
            'delta',
            'democrat',
            'dental',
            'dentist',
            'desi',
            'design',
            'dev',
            'dhl',
            'diamonds',
            'diet',
            'digital',
            'direct',
            'directory',
            'discount',
            'discover',
            'dish',
            'diy',
            'dnp',
            'docs',
            'doctor',
            'dodge',
            'dog',
            'doha',
            'domains',
            'doosan',
            'dot',
            'download',
            'drive',
            'dtv',
            'dubai',
            'duck',
            'dunlop',
            'duns',
            'dupont',
            'durban',
            'dvag',
            'dvr',
            'earth',
            'eat',
            'eco',
            'edeka',
            'education',
            'email',
            'emerck',
            'energy',
            'engineer',
            'engineering',
            'enterprises',
            'epost',
            'epson',
            'equipment',
            'ericsson',
            'erni',
            'esq',
            'estate',
            'esurance',
            'etisalat',
            'eurovision',
            'eus',
            'events',
            'everbank',
            'exchange',
            'expert',
            'exposed',
            'express',
            'extraspace',
            'fage',
            'fail',
            'fairwinds',
            'faith',
            'family',
            'fan',
            'fans',
            'farm',
            'farmers',
            'fashion',
            'fast',
            'fedex',
            'feedback',
            'ferrari',
            'ferrero',
            'fiat',
            'fidelity',
            'fido',
            'film',
            'final',
            'finance',
            'financial',
            'fire',
            'firestone',
            'firmdale',
            'fish',
            'fishing',
            'fit',
            'fitness',
            'flickr',
            'flights',
            'flir',
            'florist',
            'flowers',
            'flsmidth',
            'fly',
            'foo',
            'food',
            'foodnetwork',
            'football',
            'ford',
            'forex',
            'forsale',
            'forum',
            'foundation',
            'fox',
            'free',
            'fresenius',
            'frl',
            'frogans',
            'frontdoor',
            'frontier',
            'ftr',
            'fujitsu',
            'fujixerox',
            'fun',
            'fund',
            'furniture',
            'futbol',
            'fyi',
            'gal',
            'gallery',
            'gallo',
            'gallup',
            'game',
            'games',
            'gap',
            'garden',
            'gay',
            'gbiz',
            'gdn',
            'gea',
            'gent',
            'genting',
            'george',
            'ggee',
            'gift',
            'gifts',
            'gives',
            'giving',
            'glade',
            'glass',
            'gle',
            'global',
            'globo',
            'gmail',
            'gmbh',
            'gmo',
            'gmx',
            'godaddy',
            'gold',
            'goldpoint',
            'golf',
            'goo',
            'goodhands',
            'goodyear',
            'goog',
            'google',
            'gop',
            'got',
            'grainger',
            'graphics',
            'gratis',
            'green',
            'gripe',
            'grocery',
            'group',
            'guardian',
            'gucci',
            'guge',
            'guide',
            'guitars',
            'guru',
            'hair',
            'hamburg',
            'hangout',
            'haus',
            'hbo',
            'hdfc',
            'hdfcbank',
            'health',
            'healthcare',
            'help',
            'helsinki',
            'here',
            'hermes',
            'hgtv',
            'hiphop',
            'hisamitsu',
            'hitachi',
            'hiv',
            'hkt',
            'hockey',
            'holdings',
            'holiday',
            'homedepot',
            'homegoods',
            'homes',
            'homesense',
            'honda',
            'honeywell',
            'horse',
            'hospital',
            'host',
            'hosting',
            'hot',
            'hoteles',
            'hotels',
            'hotmail',
            'house',
            'how',
            'hsbc',
            'htc',
            'hughes',
            'hyatt',
            'hyundai',
            'ibm',
            'icbc',
            'ice',
            'icu',
            'ieee',
            'ifm',
            'iinet',
            'ikano',
            'imamat',
            'imdb',
            'immo',
            'immobilien',
            'inc',
            'industries',
            'infiniti',
            'info',
            'ing',
            'ink',
            'institute',
            'insurance',
            'insure',
            'intel',
            'international',
            'intuit',
            'investments',
            'ipiranga',
            'irish',
            'iselect',
            'ismaili',
            'ist',
            'istanbul',
            'itau',
            'itv',
            'iveco',
            'iwc',
            'jaguar',
            'java',
            'jcb',
            'jcp',
            'jeep',
            'jetzt',
            'jewelry',
            'jio',
            'jlc',
            'jll',
            'jmp',
            'jnj',
            'joburg',
            'jot',
            'joy',
            'jpmorgan',
            'jprs',
            'juegos',
            'juniper',
            'kaufen',
            'kddi',
            'kerryhotels',
            'kerrylogistics',
            'kerryproperties',
            'kfh',
            'kia',
            'kids',
            'kim',
            'kinder',
            'kindle',
            'kitchen',
            'kiwi',
            'koeln',
            'komatsu',
            'kosher',
            'kpmg',
            'kpn',
            'krd',
            'kred',
            'kuokgroup',
            'kyoto',
            'lacaixa',
            'ladbrokes',
            'lamborghini',
            'lamer',
            'lancaster',
            'lancia',
            'lancome',
            'land',
            'landrover',
            'lanxess',
            'lasalle',
            'lat',
            'latino',
            'latrobe',
            'law',
            'lawyer',
            'lds',
            'lease',
            'leclerc',
            'lefrak',
            'legal',
            'lego',
            'lexus',
            'lgbt',
            'liaison',
            'lidl',
            'life',
            'lifeinsurance',
            'lifestyle',
            'lighting',
            'like',
            'lilly',
            'limited',
            'limo',
            'lincoln',
            'linde',
            'link',
            'lipsy',
            'live',
            'living',
            'lixil',
            'llc',
            'llp',
            'loan',
            'loans',
            'locker',
            'locus',
            'loft',
            'lol',
            'london',
            'lotte',
            'lotto',
            'love',
            'lpl',
            'lplfinancial',
            'ltd',
            'ltda',
            'lundbeck',
            'lupin',
            'luxe',
            'luxury',
            'macys',
            'madrid',
            'maif',
            'maison',
            'makeup',
            'man',
            'management',
            'mango',
            'map',
            'market',
            'marketing',
            'markets',
            'marriott',
            'marshalls',
            'maserati',
            'mattel',
            'mba',
            'mcd',
            'mcdonalds',
            'mckinsey',
            'med',
            'media',
            'meet',
            'melbourne',
            'meme',
            'memorial',
            'men',
            'menu',
            'meo',
            'merckmsd',
            'metlife',
            'miami',
            'microsoft',
            'mini',
            'mint',
            'mit',
            'mitsubishi',
            'mlb',
            'mls',
            'mma',
            'mobi',
            'mobile',
            'mobily',
            'moda',
            'moe',
            'moi',
            'mom',
            'monash',
            'money',
            'monster',
            'montblanc',
            'mopar',
            'mormon',
            'mortgage',
            'moscow',
            'moto',
            'motorcycles',
            'mov',
            'movie',
            'movistar',
            'msd',
            'mtn',
            'mtpc',
            'mtr',
            'music',
            'mutual',
            'mutuelle',
            'nab',
            'nadex',
            'nagoya',
            'nationwide',
            'natura',
            'navy',
            'nba',
            'nec',
            'net',
            'netbank',
            'netflix',
            'network',
            'neustar',
            'new',
            'newholland',
            'news',
            'next',
            'nextdirect',
            'nexus',
            'nfl',
            'ngo',
            'nhk',
            'nico',
            'nike',
            'nikon',
            'ninja',
            'nissan',
            'nissay',
            'nokia',
            'northwesternmutual',
            'norton',
            'now',
            'nowruz',
            'nowtv',
            'nra',
            'nrw',
            'ntt',
            'nyc',
            'obi',
            'observer',
            'off',
            'office',
            'okinawa',
            'olayan',
            'olayangroup',
            'oldnavy',
            'ollo',
            'omega',
            'one',
            'ong',
            'onl',
            'online',
            'onyourside',
            'ooo',
            'open',
            'oracle',
            'orange',
            'org',
            'organic',
            'orientexpress',
            'origins',
            'osaka',
            'otsuka',
            'ott',
            'ovh',
            'page',
            'pamperedchef',
            'panasonic',
            'panerai',
            'paris',
            'pars',
            'partners',
            'parts',
            'party',
            'passagens',
            'pay',
            'pccw',
            'pet',
            'pfizer',
            'pharmacy',
            'phd',
            'philips',
            'phone',
            'photo',
            'photography',
            'photos',
            'physio',
            'piaget',
            'pics',
            'pictet',
            'pictures',
            'pid',
            'pin',
            'ping',
            'pink',
            'pioneer',
            'pizza',
            'place',
            'play',
            'playstation',
            'plumbing',
            'plus',
            'pnc',
            'pohl',
            'poker',
            'politie',
            'porn',
            'pramerica',
            'praxi',
            'press',
            'prime',
            'prod',
            'productions',
            'prof',
            'progressive',
            'promo',
            'properties',
            'property',
            'protection',
            'pru',
            'prudential',
            'pub',
            'pwc',
            'qpon',
            'quebec',
            'quest',
            'qvc',
            'racing',
            'radio',
            'raid',
            'read',
            'realestate',
            'realtor',
            'realty',
            'recipes',
            'red',
            'redstone',
            'redumbrella',
            'rehab',
            'reise',
            'reisen',
            'reit',
            'reliance',
            'ren',
            'rent',
            'rentals',
            'repair',
            'report',
            'republican',
            'rest',
            'restaurant',
            'review',
            'reviews',
            'rexroth',
            'rich',
            'richardli',
            'ricoh',
            'rightathome',
            'ril',
            'rio',
            'rip',
            'rmit',
            'rocher',
            'rocks',
            'rodeo',
            'rogers',
            'room',
            'rsvp',
            'rugby',
            'ruhr',
            'run',
            'rwe',
            'ryukyu',
            'saarland',
            'safe',
            'safety',
            'sakura',
            'sale',
            'salon',
            'samsclub',
            'samsung',
            'sandvik',
            'sandvikcoromant',
            'sanofi',
            'sap',
            'sapo',
            'sarl',
            'sas',
            'save',
            'saxo',
            'sbi',
            'sbs',
            'sca',
            'scb',
            'schaeffler',
            'schmidt',
            'scholarships',
            'school',
            'schule',
            'schwarz',
            'science',
            'scjohnson',
            'scor',
            'scot',
            'search',
            'seat',
            'secure',
            'security',
            'seek',
            'select',
            'sener',
            'services',
            'ses',
            'seven',
            'sew',
            'sex',
            'sexy',
            'sfr',
            'shangrila',
            'sharp',
            'shaw',
            'shell',
            'shia',
            'shiksha',
            'shoes',
            'shop',
            'shopping',
            'shouji',
            'show',
            'showtime',
            'shriram',
            'silk',
            'sina',
            'singles',
            'site',
            'ski',
            'skin',
            'sky',
            'skype',
            'sling',
            'smart',
            'smile',
            'sncf',
            'soccer',
            'social',
            'softbank',
            'software',
            'sohu',
            'solar',
            'solutions',
            'song',
            'sony',
            'soy',
            'spa',
            'space',
            'spiegel',
            'sport',
            'spot',
            'spreadbetting',
            'srl',
            'srt',
            'stada',
            'staples',
            'star',
            'starhub',
            'statebank',
            'statefarm',
            'statoil',
            'stc',
            'stcgroup',
            'stockholm',
            'storage',
            'store',
            'stream',
            'studio',
            'study',
            'style',
            'sucks',
            'supplies',
            'supply',
            'support',
            'surf',
            'surgery',
            'suzuki',
            'swatch',
            'swiftcover',
            'swiss',
            'sydney',
            'symantec',
            'systems',
            'tab',
            'taipei',
            'talk',
            'taobao',
            'target',
            'tatamotors',
            'tatar',
            'tattoo',
            'tax',
            'taxi',
            'tci',
            'tdk',
            'team',
            'tech',
            'technology',
            'telecity',
            'telefonica',
            'temasek',
            'tennis',
            'teva',
            'thd',
            'theater',
            'theatre',
            'tiaa',
            'tickets',
            'tienda',
            'tiffany',
            'tips',
            'tires',
            'tirol',
            'tjmaxx',
            'tjx',
            'tkmaxx',
            'tmall',
            'today',
            'tokyo',
            'tools',
            'top',
            'toray',
            'toshiba',
            'total',
            'tours',
            'town',
            'toyota',
            'toys',
            'trade',
            'trading',
            'training',
            'travelchannel',
            'travelers',
            'travelersinsurance',
            'trust',
            'trv',
            'tube',
            'tui',
            'tunes',
            'tushu',
            'tvs',
            'ubank',
            'ubs',
            'uconnect',
            'unicom',
            'university',
            'uno',
            'uol',
            'ups',
            'vacations',
            'vana',
            'vanguard',
            'vegas',
            'ventures',
            'verisign',
            'versicherung',
            'vet',
            'viajes',
            'video',
            'vig',
            'viking',
            'villas',
            'vin',
            'vip',
            'virgin',
            'visa',
            'vision',
            'vista',
            'vistaprint',
            'viva',
            'vivo',
            'vlaanderen',
            'vodka',
            'volkswagen',
            'volvo',
            'vote',
            'voting',
            'voto',
            'voyage',
            'vuelos',
            'wales',
            'walmart',
            'walter',
            'wang',
            'wanggou',
            'warman',
            'watch',
            'watches',
            'weather',
            'weatherchannel',
            'webcam',
            'weber',
            'website',
            'wed',
            'wedding',
            'weibo',
            'weir',
            'whoswho',
            'wien',
            'wiki',
            'williamhill',
            'win',
            'windows',
            'wine',
            'winners',
            'wme',
            'wolterskluwer',
            'woodside',
            'work',
            'works',
            'world',
            'wow',
            'wtc',
            'wtf',
            'xbox',
            'xerox',
            'xfinity',
            'xihuan',
            'xin',
            'xperia',
            'xyz',
            'yachts',
            'yahoo',
            'yamaxun',
            'yandex',
            'yodobashi',
            'yoga',
            'yokohama',
            'you',
            'youtube',
            'yun',
            'zappos',
            'zara',
            'zero',
            'zip',
            'zippo',
            'zone',
            'zuerich',
        ]
        return gtld_extensions

    @staticmethod
    def country_codes():
        country_extensions = [
            'ac',
            'ad',
            'ae',
            'af',
            'ag',
            'ai',
            'al',
            'am',
            'an',
            'ao',
            'aq',
            'ar',
            'as',
            'at',
            'au',
            'aw',
            'ax',
            'az',
            'ba',
            'bb',
            'bd',
            'be',
            'bf',
            'bg',
            'bh',
            'bi',
            'bj',
            'bl',
            'bm',
            'bn',
            'bo',
            'bq',
            'br',
            'bs',
            'bt',
            'bv',
            'bw',
            'by',
            'bz',
            'ca',
            'cc',
            'cd',
            'cf',
            'cg',
            'ch',
            'ci',
            'ck',
            'cl',
            'cm',
            'cn',
            'co',
            'cr',
            'cu',
            'cv',
            'cw',
            'cx',
            'cy',
            'cz',
            'de',
            'dj',
            'dk',
            'dm',
            'do',
            'dz',
            'ec',
            'ee',
            'eg',
            'eh',
            'er',
            'es',
            'et',
            'eu',
            'fi',
            'fj',
            'fk',
            'fm',
            'fo',
            'fr',
            'ga',
            'gb',
            'gd',
            'ge',
            'gf',
            'gg',
            'gh',
            'gi',
            'gl',
            'gm',
            'gn',
            'gp',
            'gq',
            'gr',
            'gs',
            'gt',
            'gu',
            'gw',
            'gy',
            'hk',
            'hm',
            'hn',
            'hr',
            'ht',
            'hu',
            'id',
            'ie',
            'il',
            'im',
            'in',
            'io',
            'iq',
            'ir',
            'is',
            'it',
            'je',
            'jm',
            'jo',
            'jp',
            'ke',
            'kg',
            'kh',
            'ki',
            'km',
            'kn',
            'kp',
            'kr',
            'kw',
            'ky',
            'kz',
            'la',
            'lb',
            'lc',
            'li',
            'lk',
            'lr',
            'ls',
            'lt',
            'lu',
            'lv',
            'ly',
            'ma',
            'mc',
            'md',
            'me',
            'mf',
            'mg',
            'mh',
            'mk',
            'ml',
            'mm',
            'mn',
            'mo',
            'mp',
            'mq',
            'mr',
            'ms',
            'mt',
            'mu',
            'mv',
            'mw',
            'mx',
            'my',
            'mz',
            'na',
            'nc',
            'ne',
            'nf',
            'ng',
            'ni',
            'nl',
            'no',
            'np',
            'nr',
            'nu',
            'nz',
            'om',
            'pa',
            'pe',
            'pf',
            'pg',
            'ph',
            'pk',
            'pl',
            'pm',
            'pn',
            'pr',
            'ps',
            'pt',
            'pw',
            'py',
            'qa',
            're',
            'ro',
            'rs',
            'ru',
            'rw',
            'sa',
            'sb',
            'sc',
            'sd',
            'se',
            'sg',
            'sh',
            'si',
            'sj',
            'sk',
            'sl',
            'sm',
            'sn',
            'so',
            'sr',
            'ss',
            'st',
            'su',
            'sv',
            'sx',
            'sy',
            'sz',
            'tc',
            'td',
            'tf',
            'tg',
            'th',
            'tj',
            'tk',
            'tl',
            'tm',
            'tn',
            'to',
            'tp',
            'tr',
            'tt',
            'tv',
            'tw',
            'tz',
            'ua',
            'ug',
            'uk',
            'um' 'us',
            'uy',
            'uz',
            'va',
            'vc',
            've',
            'vg',
            'vi',
            'vn',
            'vu',
            'wf',
            'ws',
            'ye',
            'yt',
            'za',
            'zm',
            'zw',
        ]
        return country_extensions

    @staticmethod
    def sponsored_tlds():
        sponsored_extensions = [
            'aaa',
            'aarp',
            'abb',
            'abbott',
            'abbvie',
            'abc',
            'able',
            'abogado',
            'abudhabi',
            'academy',
            'accenture',
            'accountant',
            'accountants',
            'aco',
            'actor',
            'ads',
            'adult',
            'aeg',
            'aetna',
            'afl',
            'africa',
            'agakhan',
            'agency',
            'aig',
            'airbus',
            'airforce',
            'airtel',
            'akdn',
            'alibaba',
            'alipay',
            'allfinanz',
            'allstate',
            'ally',
            'alsace',
            'alstom',
            'amazon',
            'americanexpress',
            'americanfamily',
            'amex',
            'amfam',
            'amica',
            'amsterdam',
            'analytics',
            'android',
            'anquan',
            'anz',
            'aol',
            'apartments',
            'app',
            'apple',
            'aquarelle',
            'arab',
            'aramco',
            'archi',
            'army',
            'art',
            'arte',
            'asda',
            'associates',
            'athleta',
            'attorney',
            'auction',
            'audi',
            'audible',
            'audio',
            'auspost',
            'author',
            'auto',
            'autos',
            'aws',
            'axa',
            'azure',
            'baby',
            'baidu',
            'banamex',
            'band',
            'bank',
            'bar',
            'barcelona',
            'barclaycard',
            'barclays',
            'barefoot',
            'bargains',
            'baseball',
            'basketball',
            'bauhaus',
            'bayern',
            'bbc',
            'bbt',
            'bbva',
            'bcg',
            'bcn',
            'beats',
            'beauty',
            'beer',
            'bentley',
            'berlin',
            'best',
            'bestbuy',
            'bet',
            'bharti',
            'bible',
            'bid',
            'bike',
            'bing',
            'bingo',
            'bio',
            'black',
            'blackfriday',
            'blockbuster',
            'blog',
            'bloomberg',
            'blue',
            'bms',
            'bmw',
            'bnpparibas',
            'boats',
            'boehringer',
            'bofa',
            'bom',
            'bond',
            'boo',
            'book',
            'booking',
            'bosch',
            'bostik',
            'boston',
            'bot',
            'boutique',
            'box',
            'bradesco',
            'bridgestone',
            'broadway',
            'broker',
            'brother',
            'brussels',
            'build',
            'builders',
            'business',
            'buy',
            'buzz',
            'bzh',
            'cab',
            'cafe',
            'cal',
            'call',
            'calvinklein',
            'cam',
            'camera',
            'camp',
            'canon',
            'capetown',
            'capital',
            'capitalone',
            'car',
            'caravan',
            'cards',
            'care',
            'career',
            'careers',
            'cars',
            'casa',
            'case',
            'cash',
            'casino',
            'catering',
            'catholic',
            'cba',
            'cbn',
            'cbre',
            'center',
            'ceo',
            'cern',
            'cfa',
            'cfd',
            'chanel',
            'channel',
            'charity',
            'chase',
            'chat',
            'cheap',
            'chintai',
            'christmas',
            'chrome',
            'church',
            'cipriani',
            'circle',
            'cisco',
            'citadel',
            'citi',
            'citic',
            'city',
            'claims',
            'cleaning',
            'click',
            'clinic',
            'clinique',
            'clothing',
            'cloud',
            'club',
            'clubmed',
            'coach',
            'codes',
            'coffee',
            'college',
            'cologne',
            'com',
            'commbank',
            'community',
            'company',
            'compare',
            'computer',
            'comsec',
            'condos',
            'construction',
            'consulting',
            'contact',
            'contractors',
            'cooking',
            'cool',
            'corsica',
            'country',
            'coupon',
            'coupons',
            'courses',
            'cpa',
            'credit',
            'creditcard',
            'creditunion',
            'cricket',
            'crown',
            'crs',
            'cruise',
            'cruises',
            'cuisinella',
            'cymru',
            'cyou',
            'dad',
            'dance',
            'data',
            'date',
            'dating',
            'datsun',
            'day',
            'dclk',
            'dds',
            'deal',
            'dealer',
            'deals',
            'degree',
            'delivery',
            'dell',
            'deloitte',
            'delta',
            'democrat',
            'dental',
            'dentist',
            'desi',
            'design',
            'dev',
            'dhl',
            'diamonds',
            'diet',
            'digital',
            'direct',
            'directory',
            'discount',
            'discover',
            'dish',
            'diy',
            'dnp',
            'docs',
            'doctor',
            'dog',
            'domains',
            'dot',
            'download',
            'drive',
            'dtv',
            'dubai',
            'dunlop',
            'dupont',
            'durban',
            'dvag',
            'dvr',
            'earth',
            'eat',
            'eco',
            'edeka',
            'education',
            'email',
            'emerck',
            'energy',
            'engineer',
            'engineering',
            'enterprises',
            'epson',
            'equipment',
            'ericsson',
            'erni',
            'esq',
            'estate',
            'eurovision',
            'eus',
            'events',
            'exchange',
            'expert',
            'exposed',
            'express',
            'extraspace',
            'fage',
            'fail',
            'fairwinds',
            'faith',
            'family',
            'fan',
            'fans',
            'farm',
            'farmers',
            'fashion',
            'fast',
            'fedex',
            'feedback',
            'ferrari',
            'ferrero',
            'fidelity',
            'fido',
            'film',
            'final',
            'finance',
            'financial',
            'fire',
            'firestone',
            'firmdale',
            'fish',
            'fishing',
            'fit',
            'fitness',
            'flickr',
            'flights',
            'flir',
            'florist',
            'flowers',
            'fly',
            'foo',
            'food',
            'football',
            'ford',
            'forex',
            'forsale',
            'forum',
            'foundation',
            'fox',
            'free',
            'fresenius',
            'frl',
            'frogans',
            'frontier',
            'ftr',
            'fujitsu',
            'fun',
            'fund',
            'furniture',
            'futbol',
            'fyi',
            'gal',
            'gallery',
            'gallo',
            'gallup',
            'game',
            'games',
            'gap',
            'garden',
            'gay',
            'gbiz',
            'gdn',
            'gea',
            'gent',
            'genting',
            'george',
            'ggee',
            'gift',
            'gifts',
            'gives',
            'giving',
            'glass',
            'gle',
            'global',
            'globo',
            'gmail',
            'gmbh',
            'gmo',
            'gmx',
            'godaddy',
            'gold',
            'goldpoint',
            'golf',
            'goo',
            'goodyear',
            'goog',
            'google',
            'gop',
            'got',
            'grainger',
            'graphics',
            'gratis',
            'green',
            'gripe',
            'grocery',
            'group',
            'gucci',
            'guge',
            'guide',
            'guitars',
            'guru',
            'hair',
            'hamburg',
            'hangout',
            'haus',
            'hbo',
            'hdfc',
            'hdfcbank',
            'health',
            'healthcare',
            'help',
            'helsinki',
            'here',
            'hermes',
            'hiphop',
            'hisamitsu',
            'hitachi',
            'hiv',
            'hkt',
            'hockey',
            'holdings',
            'holiday',
            'homedepot',
            'homegoods',
            'homes',
            'homesense',
            'honda',
            'horse',
            'hospital',
            'host',
            'hosting',
            'hot',
            'hotels',
            'hotmail',
            'house',
            'how',
            'hsbc',
            'hughes',
            'hyatt',
            'hyundai',
            'ibm',
            'icbc',
            'ice',
            'icu',
            'ieee',
            'ifm',
            'ikano',
            'imamat',
            'imdb',
            'immo',
            'immobilien',
            'inc',
            'industries',
            'infiniti',
            'info',
            'ing',
            'ink',
            'institute',
            'insurance',
            'insure',
            'international',
            'intuit',
            'investments',
            'ipiranga',
            'irish',
            'ismaili',
            'ist',
            'istanbul',
            'itau',
            'itv',
            'jaguar',
            'java',
            'jcb',
            'jeep',
            'jetzt',
            'jewelry',
            'jio',
            'jll',
            'jmp',
            'jnj',
            'joburg',
            'jot',
            'joy',
            'jpmorgan',
            'jprs',
            'juegos',
            'juniper',
            'kaufen',
            'kddi',
            'kerryhotels',
            'kerrylogistics',
            'kerryproperties',
            'kfh',
            'kia',
            'kids',
            'kim',
            'kindle',
            'kitchen',
            'kiwi',
            'koeln',
            'komatsu',
            'kosher',
            'kpmg',
            'kpn',
            'krd',
            'kred',
            'kuokgroup',
            'kyoto',
            'lacaixa',
            'lamborghini',
            'lamer',
            'lancaster',
            'land',
            'landrover',
            'lanxess',
            'lasalle',
            'lat',
            'latino',
            'latrobe',
            'law',
            'lawyer',
            'lds',
            'lease',
            'leclerc',
            'lefrak',
            'legal',
            'lego',
            'lexus',
            'lgbt',
            'lidl',
            'life',
            'lifeinsurance',
            'lifestyle',
            'lighting',
            'like',
            'lilly',
            'limited',
            'limo',
            'lincoln',
            'link',
            'lipsy',
            'live',
            'living',
            'llc',
            'llp',
            'loan',
            'loans',
            'locker',
            'locus',
            'lol',
            'london',
            'lotte',
            'lotto',
            'love',
            'lpl',
            'lplfinancial',
            'ltd',
            'ltda',
            'lundbeck',
            'luxe',
            'luxury',
            'madrid',
            'maif',
            'maison',
            'makeup',
            'man',
            'management',
            'mango',
            'map',
            'market',
            'marketing',
            'markets',
            'marriott',
            'marshalls',
            'mattel',
            'mba',
            'mckinsey',
            'med',
            'media',
            'meet',
            'melbourne',
            'meme',
            'memorial',
            'men',
            'menu',
            'merckmsd',
            'miami',
            'microsoft',
            'mini',
            'mint',
            'mit',
            'mitsubishi',
            'mlb',
            'mls',
            'mma',
            'mobi',
            'mobile',
            'moda',
            'moe',
            'moi',
            'mom',
            'monash',
            'money',
            'monster',
            'mormon',
            'mortgage',
            'moscow',
            'moto',
            'motorcycles',
            'mov',
            'movie',
            'msd',
            'mtn',
            'mtr',
            'music',
            'nab',
            'nagoya',
            'navy',
            'nba',
            'nec',
            'net',
            'netbank',
            'netflix',
            'network',
            'neustar',
            'new',
            'news',
            'next',
            'nextdirect',
            'nexus',
            'nfl',
            'ngo',
            'nhk',
            'nico',
            'nike',
            'nikon',
            'ninja',
            'nissan',
            'nissay',
            'nokia',
            'norton',
            'now',
            'nowruz',
            'nowtv',
            'nra',
            'nrw',
            'ntt',
            'nyc',
            'obi',
            'observer',
            'office',
            'okinawa',
            'olayan',
            'olayangroup',
            'ollo',
            'omega',
            'one',
            'ong',
            'onl',
            'online',
            'ooo',
            'open',
            'oracle',
            'orange',
            'org',
            'organic',
            'origins',
            'osaka',
            'otsuka',
            'ott',
            'ovh',
            'page',
            'panasonic',
            'paris',
            'pars',
            'partners',
            'parts',
            'party',
            'pay',
            'pccw',
            'pet',
            'pfizer',
            'pharmacy',
            'phd',
            'philips',
            'phone',
            'photo',
            'photography',
            'photos',
            'physio',
            'pics',
            'pictet',
            'pictures',
            'pid',
            'pin',
            'ping',
            'pink',
            'pioneer',
            'pizza',
            'place',
            'play',
            'playstation',
            'plumbing',
            'plus',
            'pnc',
            'pohl',
            'poker',
            'politie',
            'porn',
            'pramerica',
            'praxi',
            'press',
            'prime',
            'prod',
            'productions',
            'prof',
            'progressive',
            'promo',
            'properties',
            'property',
            'protection',
            'pru',
            'prudential',
            'pub',
            'pwc',
            'qpon',
            'quebec',
            'quest',
            'racing',
            'radio',
            'read',
            'realestate',
            'realtor',
            'realty',
            'recipes',
            'red',
            'redstone',
            'redumbrella',
            'rehab',
            'reise',
            'reisen',
            'reit',
            'reliance',
            'ren',
            'rent',
            'rentals',
            'repair',
            'report',
            'republican',
            'rest',
            'restaurant',
            'review',
            'reviews',
            'rexroth',
            'rich',
            'richardli',
            'ricoh',
            'ril',
            'rio',
            'rip',
            'rocks',
            'rodeo',
            'rogers',
            'room',
            'rsvp',
            'rugby',
            'ruhr',
            'run',
            'rwe',
            'ryukyu',
            'saarland',
            'safe',
            'safety',
            'sakura',
            'sale',
            'salon',
            'samsclub',
            'samsung',
            'sandvik',
            'sandvikcoromant',
            'sanofi',
            'sap',
            'sarl',
            'sas',
            'save',
            'saxo',
            'sbi',
            'sbs',
            'scb',
            'schaeffler',
            'schmidt',
            'scholarships',
            'school',
            'schule',
            'schwarz',
            'science',
            'scot',
            'search',
            'seat',
            'secure',
            'security',
            'seek',
            'select',
            'sener',
            'services',
            'seven',
            'sew',
            'sex',
            'sexy',
            'sfr',
            'shangrila',
            'sharp',
            'shell',
            'shia',
            'shiksha',
            'shoes',
            'shop',
            'shopping',
            'shouji',
            'show',
            'silk',
            'sina',
            'singles',
            'site',
            'ski',
            'skin',
            'sky',
            'skype',
            'sling',
            'smart',
            'smile',
            'sncf',
            'soccer',
            'social',
            'softbank',
            'software',
            'sohu',
            'solar',
            'solutions',
            'song',
            'sony',
            'soy',
            'spa',
            'space',
            'sport',
            'spot',
            'srl',
            'stada',
            'staples',
            'star',
            'statebank',
            'statefarm',
            'stc',
            'stcgroup',
            'stockholm',
            'storage',
            'store',
            'stream',
            'studio',
            'study',
            'style',
            'sucks',
            'supplies',
            'supply',
            'support',
            'surf',
            'surgery',
            'suzuki',
            'swatch',
            'swiss',
            'sydney',
            'systems',
            'tab',
            'taipei',
            'talk',
            'taobao',
            'target',
            'tatamotors',
            'tatar',
            'tattoo',
            'tax',
            'taxi',
            'tci',
            'tdk',
            'team',
            'tech',
            'technology',
            'temasek',
            'tennis',
            'teva',
            'thd',
            'theater',
            'theatre',
            'tiaa',
            'tickets',
            'tienda',
            'tips',
            'tires',
            'tirol',
            'tjmaxx',
            'tjx',
            'tkmaxx',
            'tmall',
            'today',
            'tokyo',
            'tools',
            'top',
            'toray',
            'toshiba',
            'total',
            'tours',
            'town',
            'toyota',
            'toys',
            'trade',
            'trading',
            'training',
            'travelers',
            'travelersinsurance',
            'trust',
            'trv',
            'tube',
            'tui',
            'tunes',
            'tushu',
            'tvs',
            'ubank',
            'ubs',
            'unicom',
            'university',
            'uno',
            'uol',
            'ups',
            'vacations',
            'vana',
            'vanguard',
            'vegas',
            'ventures',
            'verisign',
            'versicherung',
            'vet',
            'viajes',
            'video',
            'vig',
            'viking',
            'villas',
            'vin',
            'vip',
            'virgin',
            'visa',
            'vision',
            'viva',
            'vivo',
            'vlaanderen',
            'vodka',
            'volvo',
            'vote',
            'voting',
            'voto',
            'voyage',
            'wales',
            'walmart',
            'walter',
            'wang',
            'wanggou',
            'watch',
            'watches',
            'weather',
            'weatherchannel',
            'webcam',
            'weber',
            'website',
            'wed',
            'wedding',
            'weibo',
            'weir',
            'whoswho',
            'wien',
            'wiki',
            'williamhill',
            'win',
            'windows',
            'wine',
            'winners',
            'wme',
            'wolterskluwer',
            'woodside',
            'work',
            'works',
            'world',
            'wow',
            'wtc',
            'wtf',
            'xbox',
            'xerox',
            'xihuan',
            'xin',
            'xyz',
            'yachts',
            'yahoo',
            'yamaxun',
            'yandex',
            'yodobashi',
            'yoga',
            'yokohama',
            'you',
            'youtube',
            'yun',
            'zappos',
            'zara',
            'zero',
            'zip',
            'zone',
            'zuerich',
        ]
        return sponsored_extensions
